#ifndef _HEAP_H_
#define _HEAP_H_
#include "am.h"

#define	TINT	0
#define TCHAR	1
#define TSTR	2
#define TBOOL	3
#define TFLOAT	4
#define TFUN	10
#define TCHAIN	11

/* All items with header >= TSTRUCT have the same layout (i.e. size, args) */
#define TSTRUCT 16
#define TTUP	16
#define TVECTOR	17

/* All constructors/exceptions have an offset of TCON+ */
#define TCON	18

#ifndef UNBOXED
HEAP *mkNone(); /* legacy support - returns NULL */
HEAP *mkBool(boolean v);
HEAP *mkInt(int32 n);
HEAP *mkChar(char c);
HEAP *mkFloat(float32 f);
#endif /*UNBOXED*/

HEAP *mkFun(uint32 fn, uint16 needs, uint16 provided);
HEAP *mkChain(HEAP *chain, uint16 needs, uint16 provided);
HEAP *mkCon(uint32 tag, uint32 size);
HEAP *mkTup(uint32 size);
HEAP *mkVector(uint32 size);

void setHeap(HEAP value);

#ifdef SUPPORT_STRING
HEAP *mkString(const char *s, uint32 len);
HEAP *mkCatString(char *s1, uint32 len1, char *s2, uint32 len2);

/* 
 * Point textValue directly into the heap, this is a bit horrible, but
 * avoids the need to allocate any fixed size buffer
 */

HEAP *show(HEAP node, const char *type);
#endif /*SUPPORT_STRING*/

#endif /*_HEAP_H_*/

