#ifndef _boxes_h_
#define _boxes_h_
#include "main.h"
#include "typing.h"

/*
 * load the box/wire information
 *
 */
void initBoxes(); 

struct boxinfo_t;
typedef struct boxinfo_t boxinfo_t;

struct wireinfo_t;
typedef struct wireinfo_t wireinfo_t;

extern boxinfo_t *boxes;
extern wireinfo_t *wires;

typedef enum {
	boxinfo_none, 
	boxinfo_box, 
	boxinfo_streamin, 
	boxinfo_streamout, 
	boxinfo_interrupt, 
	boxinfo_clock, 
	boxinfo_args, 
	boxinfo_envs, 
	boxinfo_exit,
	boxinfo_mmapin,
	boxinfo_mmapout
} boxinfo_e;

struct boxinfo_t {
	char *name;
	boxinfo_e type;
	char *device; /* when type != boxinfo_box */
	int stackSize;
	int heapSize;
	int nInputs;
	int nOutputs;
	
	boolean initilizer;
	boolean handler;
	boolean fair;
	long within, timeout; /* zero = none */
	
	wireinfo_t **inputs;
	wireinfo_t **outputs;
	boxinfo_t *next;
};

struct wireinfo_t {
	int heapSize;
	int fromPos;
	int toPos;
	long within, timeout; /* zero = none */
	boxinfo_t *fromBox;
	boxinfo_t *toBox;
	wireinfo_t *next;
	type_t *type;
};

boxinfo_t *findBox(char *name); /* return NULL if not found */

int getBoxNumber(boxinfo_t *box);
int getWireNumber(wireinfo_t *wire);

/* for debug */
void dumpBoxes();
void dumpWires();

#endif /* _boxes_h_ */

