#ifndef _macros_h_
#define _macros_h_

#include <stdio.h> /* FILE */
#include "main.h"

void loadMacros(const char *fileName);

/*
 * Test if the macro exists
 *
 */
boolean isMacro(const char *name);

/*
 * Returns the raw string of the macro.
 *
 * Note: It calls program exit if the macro does not exist.
 *
 */
char *findMacro(const char *name);

/*
 * Writes the processed macro out to file.
 *
 * Format is a comma seperated list of key=type pairs.
 * The types are preceeded by a percent sign, similar to printf. 
 *  The supported types are currently %d, %f, %c, %s only.
 *  The type is used to determine the type of the argument to load from the '...'.
 *
 * Within the macro text the parameters are specified surrounded by angled braces, e.g. '<box>'
 *
 * Note: It calls program exit if the macro does not exist.
 *
 * Examples of format:
 *  1/ expandMacro(f, "doit", "box=%d, name=%s", 37, "bob");
 *     This would find macro 'doit' and replace every <box> with the number '37' and every <name> with the string 'bob'.
 *
 */
void expandMacro(FILE *file, const char *name, const char *format, ...);

void dumpMacros();

#endif /*_macros_h_*/

